==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Input/mpc/translations/mpc_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="cs">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="26"/>
        <source>Musepack Plugin</source>
        <translation>Modul Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="28"/>
        <source>Musepack Files</source>
        <translation>Soubory Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="82"/>
        <source>About Musepack Audio Plugin</source>
        <translation>O modulu Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="83"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Vstupní modul Qmmp Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="84"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="63"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="59"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="66"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="136"/>
        <source>File size:</source>
        <translation>Velikost souboru:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="183"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="103"/>
        <source>Sample rate:</source>
        <translation>Vzorkovací frekvence:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="299"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="270"/>
        <source>Track number:</source>
        <translation>Číslo stopy:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="257"/>
        <source>Year:</source>
        <translation>Rok:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="283"/>
        <source>Genre:</source>
        <translation>Žánr:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="244"/>
        <source>Comment:</source>
        <translation>Komentář:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="231"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="218"/>
        <source>Artist:</source>
        <translation>Umělec:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="205"/>
        <source>Title:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="322"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>Cesta k souboru:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="86"/>
        <source>Length:</source>
        <translation>Délka:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="123"/>
        <source>Channels:</source>
        <translation>Počet kanálů:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>Musepack Info</source>
        <translation>Informace Musepack</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="146"/>
        <source>Bitrate:</source>
        <translation>Datový tok:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="173"/>
        <source>Stream version:</source>
        <translation>Verze proudu:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="199"/>
        <source>APE Tag</source>
        <translation>Tag APE</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Input/mpc/translations/mpc_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="46"/>
        <source>Musepack Plugin</source>
        <translation>Modul Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="48"/>
        <source>Musepack Files</source>
        <translation>Soubory Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="103"/>
        <source>About Musepack Audio Plugin</source>
        <translation>O modulu Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="104"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Vstupní modul Qmmp Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="105"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="63"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="59"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="66"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="136"/>
        <source>File size:</source>
        <translation>Velikost souboru:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="79"/>
        <location filename="../detailsdialog.ui" line="96"/>
        <location filename="../detailsdialog.ui" line="113"/>
        <location filename="../detailsdialog.ui" line="159"/>
        <location filename="../detailsdialog.ui" line="166"/>
        <location filename="../detailsdialog.ui" line="183"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="103"/>
        <source>Sample rate:</source>
        <translation>Vzorkovací frekvence:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="299"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="270"/>
        <source>Track number:</source>
        <translation>Číslo stopy:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="257"/>
        <source>Year:</source>
        <translation>Rok:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="283"/>
        <source>Genre:</source>
        <translation>Žánr:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="244"/>
        <source>Comment:</source>
        <translation>Komentář:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="231"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="218"/>
        <source>Artist:</source>
        <translation>Umělec:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="205"/>
        <source>Title:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="322"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>Cesta k souboru:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="86"/>
        <source>Length:</source>
        <translation>Délka:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="123"/>
        <source>Channels:</source>
        <translation>Počet kanálů:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>Musepack Info</source>
        <translation>Informace Musepack</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="146"/>
        <source>Bitrate:</source>
        <translation>Datový tok:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="173"/>
        <source>Stream version:</source>
        <translation>Verze proudu:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="199"/>
        <source>APE Tag</source>
        <translation>Tag APE</translation>
    </message>
</context>
</TS>
